( cd usr/lib ; rm -rf libical.so.0 )
( cd usr/lib ; ln -sf libical.so.0.42.0 libical.so.0 )
( cd usr/lib ; rm -rf libicalvcal.so.0 )
( cd usr/lib ; ln -sf libicalvcal.so.0.42.0 libicalvcal.so.0 )
( cd usr/lib ; rm -rf libical.so )
( cd usr/lib ; ln -sf libical.so.0.42.0 libical.so )
( cd usr/lib ; rm -rf libicalss.so )
( cd usr/lib ; ln -sf libicalss.so.0.42.0 libicalss.so )
( cd usr/lib ; rm -rf libicalss.so.0 )
( cd usr/lib ; ln -sf libicalss.so.0.42.0 libicalss.so.0 )
( cd usr/lib ; rm -rf libicalvcal.so )
( cd usr/lib ; ln -sf libicalvcal.so.0.42.0 libicalvcal.so )
